@@ -4,8 +4,8 @@ import requests
 # This is a class that is designed to include all methods and functions one needs to make an A.P.I. call
 class API(object):
 
-    _base_url = "http://nashsync-bankcore.nashglobal.co/api/banks"
-    _base_url_third_party_banking = "http://bankingintegrations.nashglobal.co/api"
+    _base_url = "https://dev.bankingservices.nashglobal.co/api/banks"
+    _base_url_third_party_banking = "https://dev.3p.bankingservices.nashglobal.co/api"
 
     _full_url = ""
 
