@@ -3,6 +3,9 @@ from bank_sync.APIs.utils.generate_code import get_code
 from datetime import datetime
 from datetime import date
 
+import logging
+logger = logging.getLogger(__name__)
+
 
 class Accounts(Resource):
 
@@ -168,6 +171,10 @@ class Accounts(Resource):
 
         response_data = super().response()
 
+        logger.info(f'super().get_operation(): {super().get_operation()}')
+        logger.info(f'super().get_bank_id(): {super().get_bank_id()}')
+        logger.info(f'response_data: {response_data}')
+
         if super().get_operation() == super().BALANCE:
 
             if super().get_bank_id() == super().COOP:
@@ -241,7 +248,7 @@ class Accounts(Resource):
                         transaction = {
                             "currency_code": response_data.get("data", {}).get("currency", "KES"),
                             "date": datetime.fromisoformat(
-                                transactions[i].get("date", "") + '+00:00'
+                                transactions[i].get("postedDateTime", "") + '+00:00'
                             ).strftime('%Y-%m-%d %H:%M:%S'),
                             "description": transactions[i].get("description", ""),
                             "amount":  transactions[i].get("amount", ""),
@@ -312,28 +319,32 @@ class Accounts(Resource):
 
             elif super().get_bank_id() == super().EQUITY:
 
-                data["message"] = response_data.get("message", "")
-                data["code"] = f'{response_data.get("code", -111111)}'
-                data["transactions"] = []
+                if isinstance(response_data,dict):
+                    data["message"] = response_data.get("message", "")
+                    data["code"] = f'{response_data.get("code", -111111)}'
+                    data["transactions"] = []
 
-                transactions = response_data.get(
-                    "data", {}).get("transactions", [])
+                    transactions = response_data.get(
+                        "data", {}).get("transactions", [])
 
-                for i in range(len(transactions)):
+                    for i in range(len(transactions)):
 
-                    transaction = {
-                        "currency_code": response_data.get("data", {}).get("currency", "KES"),
-                        "date": datetime.fromisoformat(
-                            transactions[i].get("date", "") + '+00:00'
-                        ).strftime('%Y-%m-%d %H:%M:%S'),
-                        "description": transactions[i].get("description", ""),
-                        "amount":  f'{transactions[i].get("amount", "")}',
-                        "type":  transactions[i].get("type", ""),
-                        "reference":  transactions[i].get("reference", ""),
-                        "running_balance":  f'{transactions[i].get("runningBalance", {}).get("amount", "")}'
-                    }
+                        transaction = {
+                            "currency_code": response_data.get("data", {}).get("currency", "KES"),
+                            "date": datetime.fromisoformat(
+                                transactions[i].get("postedDateTime", "") + '+00:00'
+                            ).strftime('%Y-%m-%d %H:%M:%S'),
+                            "description": transactions[i].get("description", ""),
+                            "amount":  f'{transactions[i].get("amount", "")}',
+                            "type":  transactions[i].get("type", ""),
+                            "reference":  transactions[i].get("reference", ""),
+                            "running_balance":  f'{transactions[i].get("runningBalance", {}).get("amount", "")}'
+                        }
 
-                    data["transactions"].append(transaction)
+                        data["transactions"].append(transaction)
+                else:
+                    data['response'] = response_data
+                    
             # If bank_id is UBA
             elif super().get_bank_id() == super().UBA:
 
@@ -367,4 +378,4 @@ class Accounts(Resource):
         if bool(data):
             return data
 
-        return super().response()
+        return data
